@@ -21,11 +21,14 @@ import tarfile
 import tempfile
 import urllib.request
 from datetime import datetime
+from distutils.version import LooseVersion
 from importlib.util import module_from_spec, spec_from_file_location
-from itertools import groupby
+from itertools import chain, groupby
 from types import ModuleType
 from typing import List
 
+from pkg_resources import parse_requirements
+
 _PROJECT_ROOT = os.path.dirname(os.path.dirname(__file__))
 _PACKAGE_MAPPING = {"pytorch": "pytorch_lightning", "app": "lightning_app"}
 
@@ -42,40 +45,92 @@ def _load_py_module(name: str, location: str) -> ModuleType:
     return py
 
 
+def _augment_requirement(ln: str, comment_char: str = "#", unfreeze: str = "all") -> str:
+    """Adjust the upper version contrains.
+
+    Args:
+        ln: raw line from requirement
+        comment_char: charter marking comment
+        unfreeze: Enum or "all"|"major"|""
+
+    Returns:
+        adjusted requirement
+
+    >>> _augment_requirement("arrow>=1.2.0, <=1.2.2  # anything", unfreeze="")
+    'arrow>=1.2.0, <=1.2.2'
+    >>> _augment_requirement("arrow>=1.2.0, <=1.2.2  # strict", unfreeze="")
+    'arrow>=1.2.0, <=1.2.2  # strict'
+    >>> _augment_requirement("arrow>=1.2.0, <=1.2.2  # my name", unfreeze="all")
+    'arrow>=1.2.0'
+    >>> _augment_requirement("arrow>=1.2.0, <=1.2.2  # strict", unfreeze="all")
+    'arrow>=1.2.0, <=1.2.2  # strict'
+    >>> _augment_requirement("arrow", unfreeze="all")
+    'arrow'
+    >>> _augment_requirement("arrow>=1.2.0, <=1.2.2  # cool", unfreeze="major")
+    'arrow>=1.2.0, <2.0  # strict'
+    >>> _augment_requirement("arrow>=1.2.0, <=1.2.2  # strict", unfreeze="major")
+    'arrow>=1.2.0, <=1.2.2  # strict'
+    >>> _augment_requirement("arrow>=1.2.0", unfreeze="major")
+    'arrow>=1.2.0, <2.0  # strict'
+    >>> _augment_requirement("arrow", unfreeze="major")
+    'arrow'
+    """
+    # filer all comments
+    if comment_char in ln:
+        comment = ln[ln.index(comment_char) :]
+        ln = ln[: ln.index(comment_char)]
+        is_strict = "strict" in comment
+    else:
+        is_strict = False
+    req = ln.strip()
+    # skip directly installed dependencies
+    if not req or req.startswith("http") or "@http" in req:
+        return ""
+    # extract the major version from all listed versions
+    if unfreeze == "major":
+        req_ = list(parse_requirements([req]))[0]
+        vers = [LooseVersion(v) for s, v in req_.specs if s not in ("==", "~=")]
+        ver_major = sorted(vers)[-1].version[0] if vers else None
+    else:
+        ver_major = None
+
+    # remove version restrictions unless they are strict
+    if unfreeze and "<" in req and not is_strict:
+        req = re.sub(r",? *<=? *[\d\.\*]+", "", req).strip()
+    if ver_major is not None and not is_strict:
+        # add , only if there are already some versions
+        req += f"{',' if any(c in req for c in '<=>') else ''} <{int(ver_major) + 1}.0"
+
+    # adding strict back to the comment
+    if is_strict or ver_major is not None:
+        req += "  # strict"
+
+    return req
+
+
 def load_requirements(
-    path_dir: str, file_name: str = "base.txt", comment_char: str = "#", unfreeze: bool = True
+    path_dir: str, file_name: str = "base.txt", comment_char: str = "#", unfreeze: str = "all"
 ) -> List[str]:
-    """Load requirements from a file.
+    """Loading requirements from a file.
 
     >>> path_req = os.path.join(_PROJECT_ROOT, "requirements")
-    >>> load_requirements(path_req)  # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
-    ['numpy...', 'torch...', ...]
+    >>> load_requirements(path_req, unfreeze="major")  # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
+    ['pytorch_lightning...', 'lightning_app...']
     """
     with open(os.path.join(path_dir, file_name)) as file:
         lines = [ln.strip() for ln in file.readlines()]
     reqs = []
     for ln in lines:
-        # filer all comments
-        comment = ""
-        if comment_char in ln:
-            comment = ln[ln.index(comment_char) :]
-            ln = ln[: ln.index(comment_char)]
-        req = ln.strip()
-        # skip directly installed dependencies
-        if not req or req.startswith("http") or "@http" in req:
-            continue
-        # remove version restrictions unless they are strict
-        if unfreeze and "<" in req and "strict" not in comment:
-            req = re.sub(r",? *<=? *[\d\.\*]+", "", req).strip()
-        reqs.append(req)
-    return reqs
+        reqs.append(_augment_requirement(ln, comment_char=comment_char, unfreeze=unfreeze))
+    # filter empty lines
+    return [str(req) for req in reqs if req]
 
 
 def load_readme_description(path_dir: str, homepage: str, version: str) -> str:
     """Load readme as decribtion.
 
     >>> load_readme_description(_PROJECT_ROOT, "", "")  # doctest: +ELLIPSIS +NORMALIZE_WHITESPACE
-    '<div align="center">...'
+    '...'
     """
     path_readme = os.path.join(path_dir, "README.md")
     text = open(path_readme, encoding="utf-8").read()
@@ -94,11 +149,10 @@ def load_readme_description(path_dir: str, homepage: str, version: str) -> str:
     text = text.replace("pytorch-lightning.readthedocs.io/en/stable/", f"pytorch-lightning.readthedocs.io/en/{version}")
     # codecov badge
     text = text.replace("/branch/master/graph/badge.svg", f"/release/{version}/graph/badge.svg")
-    # replace github badges for release ones
+    # github actions badge
     text = text.replace("badge.svg?branch=master&event=push", f"badge.svg?tag={version}")
-    # Azure...
+    # azure pipelines badge
     text = text.replace("?branchName=master", f"?branchName=refs%2Ftags%2F{version}")
-    text = re.sub(r"\?definitionId=\d+&branchName=master", f"?definitionId=2&branchName=refs%2Ftags%2F{version}", text)
 
     skip_begin = r"<!-- following section will be skipped from PyPI description -->"
     skip_end = r"<!-- end skipping PyPI description -->"
@@ -123,7 +177,18 @@ def replace_block_with_imports(lines: List[str], import_path: str, kword: str =
     >>> lines = replace_block_with_imports(lines, import_path, "def")
     """
     body, tracking, skip_offset = [], False, 0
-    for ln in lines:
+    for i, ln in enumerate(lines):
+        # support for defining a class with this condition
+        conditional_class_definitions = ("if TYPE_CHECKING", "if typing.TYPE_CHECKING", "if torch.", "if _TORCH_")
+        if (
+            any(ln.startswith(pattern) for pattern in conditional_class_definitions)
+            # avoid bug in CI for the <1.7 meta code
+            and "pytorch_lightning.utilities.meta" not in import_path
+        ):
+            # dedent the next line
+            lines[i + 1] = lines[i + 1].lstrip()
+            continue
+
         offset = len(ln) - len(ln.lstrip())
         # in case of mating the class args are multi-line
         if tracking and ln and offset <= skip_offset and not any(ln.lstrip().startswith(c) for c in ")]"):
@@ -433,3 +498,35 @@ def _download_frontend(root: str = _PROJECT_ROOT):
     # If installing from source without internet connection, we don't want to break the installation
     except Exception:
         print("The Lightning UI downloading has failed!")
+
+
+def _relax_require_versions(source_dir: str = "src", req_dir: str = "requirements") -> None:
+    """Parse the base requirements and append  as version adjustments if needed `pkg>=X1.Y1.Z1,==X2.Y2.*`.
+
+    >>> _relax_require_versions("../src", "../requirements")
+    """
+    reqs = load_requirements(req_dir, file_name="base.txt")
+    for i, req in enumerate(parse_requirements(reqs)):
+        ver_ = parse_version_from_file(os.path.join(source_dir, req.name))
+        if not ver_:
+            continue
+        ver2 = ".".join(ver_.split(".")[:2] + ["*"])
+        reqs[i] = f"{req}, =={ver2}"
+
+    with open(os.path.join(req_dir, "base.txt"), "w") as fp:
+        fp.writelines([ln + os.linesep for ln in reqs])
+
+
+def _load_aggregate_requirements(req_dir: str = "requirements", freeze_requirements: bool = False) -> None:
+    """Load all base requirements from all particular packages and prune duplicates."""
+    requires = [
+        load_requirements(d, file_name="base.txt", unfreeze=not freeze_requirements)
+        for d in glob.glob(os.path.join(req_dir, "*"))
+        if os.path.isdir(d)
+    ]
+    if not requires:
+        return None
+    # TODO: add some smarter version aggregation per each package
+    requires = list(chain(*requires))
+    with open(os.path.join(req_dir, "base.txt"), "w") as fp:
+        fp.writelines([ln + os.linesep for ln in requires])
