@@ -11,11 +11,13 @@ from time import time
 from deepdiff import DeepDiff, Delta
 
 import lightning_app
+from lightning_app.api.request_types import APIRequest, CommandRequest, DeltaRequest
 from lightning_app.core.constants import FLOW_DURATION_SAMPLES, FLOW_DURATION_THRESHOLD, STATE_ACCUMULATE_WAIT
 from lightning_app.core.queues import BaseQueue, SingleProcessQueue
 from lightning_app.frontend import Frontend
 from lightning_app.storage.path import storage_root_dir
-from lightning_app.utilities.app_helpers import _delta_to_appstate_delta, _LightningAppRef
+from lightning_app.utilities.app_helpers import _delta_to_app_state_delta, _LightningAppRef
+from lightning_app.utilities.commands.base import _process_requests
 from lightning_app.utilities.component import _convert_paths_after_init
 from lightning_app.utilities.enum import AppStage, CacheCallsKeys
 from lightning_app.utilities.exceptions import CacheMissException, ExitAppException
@@ -72,6 +74,7 @@ class LightningApp:
         # queues definition.
         self.delta_queue: t.Optional[BaseQueue] = None
         self.readiness_queue: t.Optional[BaseQueue] = None
+        self.api_response_queue: t.Optional[BaseQueue] = None
         self.api_publish_state_queue: t.Optional[BaseQueue] = None
         self.api_delta_queue: t.Optional[BaseQueue] = None
         self.error_queue: t.Optional[BaseQueue] = None
@@ -81,6 +84,7 @@ class LightningApp:
         self.copy_response_queues: t.Optional[t.Dict[str, BaseQueue]] = None
         self.caller_queues: t.Optional[t.Dict[str, BaseQueue]] = None
         self.work_queues: t.Optional[t.Dict[str, BaseQueue]] = None
+        self.commands: t.Optional[t.List] = None
 
         self.should_publish_changes_to_api = False
         self.component_affiliation = None
@@ -89,7 +93,7 @@ class LightningApp:
         self.processes: t.Dict[str, WorkManager] = {}
         self.frontends: t.Dict[str, Frontend] = {}
         self.stage = AppStage.RUNNING
-        self._has_updated: bool = False
+        self._has_updated: bool = True
         self._schedules: t.Dict[str, t.Dict] = {}
         self.threads: t.List[threading.Thread] = []
 
@@ -197,7 +201,7 @@ class LightningApp:
 
     @staticmethod
     def populate_changes(last_state, new_state):
-        diff = DeepDiff(last_state, new_state, view="tree")
+        diff = DeepDiff(last_state, new_state, view="tree", verbose_level=2)
 
         changes_categories = [diff[key] for key in diff.to_dict()]
 
@@ -248,7 +252,7 @@ class LightningApp:
         """Returns all the works defined within this application with their names."""
         return self.root.named_works(recurse=True)
 
-    def _collect_deltas_from_ui_and_work_queues(self) -> t.List[Delta]:
+    def _collect_deltas_from_ui_and_work_queues(self) -> t.List[t.Union[Delta, APIRequest, CommandRequest]]:
         # The aggregation would try to get as many deltas as possible
         # from both the `api_delta_queue` and `delta_queue`
         # during the `state_accumulate_wait` time.
@@ -262,8 +266,12 @@ class LightningApp:
         while (time() - t0) < self.state_accumulate_wait:
 
             if self.api_delta_queue and should_get_delta_from_api:
-                delta_from_api: Delta = self.get_state_changed_from_queue(self.api_delta_queue)  # TODO: rename
+                delta_from_api: t.Union[DeltaRequest, APIRequest, CommandRequest] = self.get_state_changed_from_queue(
+                    self.api_delta_queue
+                )  # TODO: rename
                 if delta_from_api:
+                    if isinstance(delta_from_api, DeltaRequest):
+                        delta_from_api = delta_from_api.delta
                     deltas.append(delta_from_api)
                 else:
                     should_get_delta_from_api = False
@@ -273,7 +281,7 @@ class LightningApp:
                 if component_output:
                     logger.debug(f"Received from {component_output.id} : {component_output.delta.to_dict()}")
                     work = self.get_component_by_name(component_output.id)
-                    new_work_delta = _delta_to_appstate_delta(self.root, work, deepcopy(component_output.delta))
+                    new_work_delta = _delta_to_app_state_delta(self.root, work, deepcopy(component_output.delta))
                     deltas.append(new_work_delta)
                 else:
                     should_get_component_output = False
@@ -302,16 +310,29 @@ class LightningApp:
         if not deltas:
             # When no deltas are received from the Rest API or work queues,
             # we need to check if the flow modified the state and populate changes.
-            if Delta(DeepDiff(self.last_state, self.state)).to_dict():
+            deep_diff = DeepDiff(self.last_state, self.state, verbose_level=2)
+            if deep_diff:
+                # TODO: Resolve changes with ``CacheMissException``.
                 # new_state = self.populate_changes(self.last_state, self.state)
-                self.set_state(self.state)
+                self.set_last_state(self.state)
                 self._has_updated = True
             return False
 
         logger.debug(f"Received {[d.to_dict() for d in deltas]}")
 
-        state = self.state
+        # 1: Process the API / Command Requests first as they might affect the state.
+        state_deltas = []
         for delta in deltas:
+            if isinstance(delta, (APIRequest, CommandRequest)):
+                _process_requests(self, delta)
+            else:
+                state_deltas.append(delta)
+
+        # 2: Collect the state
+        state = self.state
+
+        # 3: Apply the state delta
+        for delta in state_deltas:
             try:
                 state += delta
             except Exception as e:
@@ -324,7 +345,6 @@ class LightningApp:
     def run_once(self):
         """Method used to collect changes and run the root Flow once."""
         done = False
-        self._has_updated = False
         self._last_run_time = 0.0
 
         if self.backend is not None:
@@ -345,17 +365,23 @@ class LightningApp:
         elif self.stage == AppStage.RESTARTING:
             return self._apply_restarting()
 
+        t0 = time()
+
         try:
             self.check_error_queue()
-            t0 = time()
-            self.root.run()
-            self._last_run_time = time() - t0
+            # Execute the flow only if:
+            # - There are state changes
+            # - It is the first execution of the flow
+            if self._has_updated:
+                self.root.run()
         except CacheMissException:
             self._on_cache_miss_exception()
         except (ExitAppException, KeyboardInterrupt):
             done = True
             self.stage = AppStage.STOPPING
 
+        self._last_run_time = time() - t0
+
         self.on_run_once_end()
         return done
 
@@ -405,6 +431,8 @@ class LightningApp:
             if self._has_updated and self.should_publish_changes_to_api and self.api_publish_state_queue:
                 self.api_publish_state_queue.put(self.state_vars)
 
+            self._has_updated = False
+
         return True
 
     def _update_layout(self) -> None:
@@ -421,8 +449,10 @@ class LightningApp:
         self.stage = AppStage.BLOCKING
         return False
 
-    def _has_work_finished(self, work):
+    def _has_work_finished(self, work) -> bool:
         latest_call_hash = work._calls[CacheCallsKeys.LATEST_CALL_HASH]
+        if latest_call_hash is None:
+            return False
         return "ret" in work._calls[latest_call_hash]
 
     def _collect_work_finish_status(self) -> dict:
