@@ -1,5 +1,6 @@
 from lightning_app.frontend.frontend import Frontend
+from lightning_app.frontend.panel import PanelFrontend
 from lightning_app.frontend.stream_lit import StreamlitFrontend
 from lightning_app.frontend.web import StaticWebFrontend
 
-__all__ = ["Frontend", "StaticWebFrontend", "StreamlitFrontend"]
+__all__ = ["Frontend", "PanelFrontend", "StaticWebFrontend", "StreamlitFrontend"]
