@@ -3,10 +3,13 @@ import os
 from dataclasses import dataclass
 from typing import Any, Callable, Optional, Union
 
+from lightning_app.api.http_methods import _add_tags_to_api, _validate_api
 from lightning_app.core.api import start_server
 from lightning_app.runners.backends import Backend
 from lightning_app.runners.runtime import Runtime
 from lightning_app.storage.orchestrator import StorageOrchestrator
+from lightning_app.utilities.app_helpers import is_overridden
+from lightning_app.utilities.commands.base import _commands_to_api, _prepare_commands
 from lightning_app.utilities.component import _set_flow_context, _set_frontend_context
 from lightning_app.utilities.load_app import extract_metadata_from_app
 from lightning_app.utilities.network import find_free_network_port
@@ -60,9 +63,22 @@ class MultiProcessRuntime(Runtime):
             if self.start_server:
                 self.app.should_publish_changes_to_api = True
                 has_started_queue = self.backend.queues.get_has_server_started_queue()
+
+                apis = []
+                if is_overridden("configure_api", self.app.root):
+                    apis = self.app.root.configure_api()
+                    _validate_api(apis)
+                    _add_tags_to_api(apis, ["app_api"])
+
+                if is_overridden("configure_commands", self.app.root):
+                    commands = _prepare_commands(self.app)
+                    apis += _commands_to_api(commands)
+
                 kwargs = dict(
+                    apis=apis,
                     host=self.host,
                     port=self.port,
+                    api_response_queue=self.app.api_response_queue,
                     api_publish_state_queue=self.app.api_publish_state_queue,
                     api_delta_queue=self.app.api_delta_queue,
                     has_started_queue=has_started_queue,
