@@ -3,6 +3,7 @@ import json
 import logging
 import os
 import shutil
+import subprocess
 import sys
 import tempfile
 import time
@@ -141,9 +142,32 @@ def browser_context_args(browser_context_args: Dict) -> Dict:
     }
 
 
+@contextmanager
+def run_cli(args) -> Generator:
+    """This utility is used to automate end-to-end testing of the Lightning AI CLI."""
+    cmd = [
+        sys.executable,
+        "-m",
+        "lightning",
+    ] + args
+
+    with tempfile.TemporaryDirectory() as tmpdir:
+        env_copy = os.environ.copy()
+        process = Popen(
+            cmd,
+            cwd=tmpdir,
+            env=env_copy,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        )
+        process.wait()
+
+    yield process.stdout.read().decode("UTF-8"), process.stderr.read().decode("UTF-8")
+
+
 @requires("playwright")
 @contextmanager
-def run_app_in_cloud(app_folder: str, app_name: str = "app.py") -> Generator:
+def run_app_in_cloud(app_folder: str, app_name: str = "app.py", extra_args: [str] = []) -> Generator:
     """This utility is used to automate testing e2e application with lightning_app.ai."""
     # 1. Validate the provide app_folder is correct.
     if not os.path.exists(os.path.join(app_folder, "app.py")):
@@ -160,26 +184,32 @@ def run_app_in_cloud(app_folder: str, app_name: str = "app.py") -> Generator:
     else:
         name = f"test-{TEST_APP_NAME}-" + str(int(time.time()))
 
-    # 3. Launch the application in the cloud from the Lightning CLI.
+    # 3. Disconnect from the App if any.
+    Popen("lightning disconnect", shell=True).wait()
+
+    # 4. Launch the application in the cloud from the Lightning CLI.
     with tempfile.TemporaryDirectory() as tmpdir:
         env_copy = os.environ.copy()
         env_copy["PACKAGE_LIGHTNING"] = "1"
         shutil.copytree(app_folder, tmpdir, dirs_exist_ok=True)
         # TODO - add -no-cache to the command line.
         process = Popen(
-            [
-                sys.executable,
-                "-m",
-                "lightning",
-                "run",
-                "app",
-                app_name,
-                "--cloud",
-                "--name",
-                name,
-                "--open-ui",
-                "false",
-            ],
+            (
+                [
+                    sys.executable,
+                    "-m",
+                    "lightning",
+                    "run",
+                    "app",
+                    app_name,
+                    "--cloud",
+                    "--name",
+                    name,
+                    "--open-ui",
+                    "false",
+                ]
+                + extra_args
+            ),
             cwd=tmpdir,
             env=env_copy,
             stdout=sys.stdout,
@@ -187,21 +217,17 @@ def run_app_in_cloud(app_folder: str, app_name: str = "app.py") -> Generator:
         )
         process.wait()
 
-    # 4. Print your application name
+    # 5. Print your application name
     print(f"The Lightning App Name is: [bold magenta]{name}[/bold magenta]")
 
-    # 5. Create chromium browser, auth to lightning_app.ai and yield the admin and view pages.
+    # 6. Create chromium browser, auth to lightning_app.ai and yield the admin and view pages.
     with sync_playwright() as p:
         browser = p.chromium.launch(headless=bool(int(os.getenv("HEADLESS", "0"))))
-        payload = {
-            "apiKey": Config.api_key,
-            "username": Config.username,
-            "duration": "120000",
-        }
+        payload = {"apiKey": Config.api_key, "username": Config.username, "duration": "120000"}
         context = browser.new_context(
             # Eventually this will need to be deleted
             http_credentials=HttpCredentials(
-                {"username": os.getenv("LAI_USER").strip(), "password": os.getenv("LAI_PASS")}
+                {"username": os.getenv("LAI_USER", "").strip(), "password": os.getenv("LAI_PASS", "")}
             ),
             record_video_dir=os.path.join(Config.video_location, TEST_APP_NAME),
             record_har_path=Config.har_location,
@@ -320,13 +346,13 @@ def run_app_in_cloud(app_folder: str, app_name: str = "app.py") -> Generator:
                     print(f"[{color}]{log_event.component_name}{padding}[/{color}] {date} {message}")
                 yield message
 
-        # 5. Print your application ID
+        # 7. Print your application ID
         print(
             f"The Lightning Id Name : [bold magenta]{str(view_page.url).split('.')[0].split('//')[-1]}[/bold magenta]"
         )
 
         try:
-            yield admin_page, view_page, fetch_logs
+            yield admin_page, view_page, fetch_logs, name
         except KeyboardInterrupt:
             pass
         finally:
@@ -354,6 +380,8 @@ def run_app_in_cloud(app_folder: str, app_name: str = "app.py") -> Generator:
                 except ApiException as e:
                     print(f"Failed to delete {lightningapp.name}. Exception {e}")
 
+            Popen("lightning disconnect", shell=True).wait()
+
 
 def wait_for(page, callback: Callable, *args, **kwargs) -> Any:
     import playwright
