@@ -5,6 +5,7 @@ import signal
 import sys
 import threading
 import time
+import traceback
 import warnings
 from copy import deepcopy
 from dataclasses import dataclass
@@ -13,6 +14,7 @@ from threading import Event, Thread
 from typing import Any, Callable, Dict, Optional, Set, Tuple, TYPE_CHECKING, Union
 
 from deepdiff import DeepDiff, Delta
+from lightning_utilities.core.apply_func import apply_to_collection
 
 from lightning_app.storage import Path
 from lightning_app.storage.copier import Copier, copy_files
@@ -20,7 +22,6 @@ from lightning_app.storage.drive import _maybe_create_drive, Drive
 from lightning_app.storage.path import path_to_work_artifact
 from lightning_app.storage.payload import Payload
 from lightning_app.utilities.app_helpers import affiliation
-from lightning_app.utilities.apply_func import apply_to_collection
 from lightning_app.utilities.component import _set_work_context
 from lightning_app.utilities.enum import (
     CacheCallsKeys,
@@ -220,7 +221,7 @@ class WorkStateObserver(Thread):
             self._delta_memory.clear()
 
             # The remaining delta is the result of state updates triggered outside the setattr, e.g, by a list append
-            delta = Delta(DeepDiff(self._last_state, self._work.state))
+            delta = Delta(DeepDiff(self._last_state, self._work.state, verbose_level=2))
             if not delta.to_dict():
                 return
             self._last_state = deepcopy(self._work.state)
@@ -255,7 +256,7 @@ class LightningWorkSetAttrProxy:
         with _state_observer_lock:
             state = deepcopy(self.work.state)
             self.work._default_setattr(name, value)
-            delta = Delta(DeepDiff(state, self.work.state))
+            delta = Delta(DeepDiff(state, self.work.state, verbose_level=2))
             if not delta.to_dict():
                 return
 
@@ -407,9 +408,14 @@ class WorkRunner:
                 make_status(WorkStageStatus.FAILED, message=str(e), reason=WorkFailureReasons.USER_EXCEPTION)
             )
             self.delta_queue.put(
-                ComponentDelta(id=self.work_name, delta=Delta(DeepDiff(reference_state, self.work.state)))
+                ComponentDelta(
+                    id=self.work_name, delta=Delta(DeepDiff(reference_state, self.work.state, verbose_level=2))
+                )
             )
             self.work.on_exception(e)
+            print("########## CAPTURED EXCEPTION ###########")
+            print(traceback.print_exc())
+            print("########## CAPTURED EXCEPTION ###########")
             return
 
         # 13. Destroy the state observer.
@@ -433,7 +439,9 @@ class WorkRunner:
         reference_state = deepcopy(self.work.state)
         self.work._calls[call_hash]["statuses"].append(make_status(WorkStageStatus.SUCCEEDED))
         self.work._calls[call_hash]["ret"] = ret
-        self.delta_queue.put(ComponentDelta(id=self.work_name, delta=Delta(DeepDiff(reference_state, self.work.state))))
+        self.delta_queue.put(
+            ComponentDelta(id=self.work_name, delta=Delta(DeepDiff(reference_state, self.work.state, verbose_level=2)))
+        )
 
         # 18. Update the work for the next delta if any.
         self._proxy_setattr(cleanup=True)
@@ -448,7 +456,7 @@ class WorkRunner:
             self.work._calls[call_hash]["statuses"].append(
                 make_status(WorkStageStatus.STOPPED, reason=WorkStopReasons.SIGTERM_SIGNAL_HANDLER)
             )
-            delta = Delta(DeepDiff(state, self.work.state))
+            delta = Delta(DeepDiff(state, self.work.state, verbose_level=2))
             self.delta_queue.put(ComponentDelta(id=self.work_name, delta=delta))
 
         # kill the thread as the job is going to be terminated.
